==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionAbortHttpStatusBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HTTPFaultInjectionAbortHttpStatusBuilder extends HTTPFaultInjectionAbortHttpStatusFluentImpl<HTTPFaultInjectionAbortHttpStatusBuilder> implements VisitableBuilder<HTTPFaultInjectionAbortHttpStatus,HTTPFaultInjectionAbortHttpStatusBuilder>{
  public HTTPFaultInjectionAbortHttpStatusBuilder() {
    this(false);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(Boolean validationEnabled) {
    this(new HTTPFaultInjectionAbortHttpStatus(), validationEnabled);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HTTPFaultInjectionAbortHttpStatus(), validationEnabled);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatusFluent<?> fluent,HTTPFaultInjectionAbortHttpStatus instance) {
    this(fluent, instance, false);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatusFluent<?> fluent,HTTPFaultInjectionAbortHttpStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withHttpStatus(instance.getHttpStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatus instance) {
    this(instance,false);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withHttpStatus(instance.getHttpStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  HTTPFaultInjectionAbortHttpStatusFluent<?> fluent;
  Boolean validationEnabled;
  public HTTPFaultInjectionAbortHttpStatus build() {
    HTTPFaultInjectionAbortHttpStatus buildable = new HTTPFaultInjectionAbortHttpStatus(fluent.getHttpStatus());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionAbortHttpStatusBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HTTPFaultInjectionAbortHttpStatusBuilder extends HTTPFaultInjectionAbortHttpStatusFluent<HTTPFaultInjectionAbortHttpStatusBuilder> implements VisitableBuilder<HTTPFaultInjectionAbortHttpStatus,HTTPFaultInjectionAbortHttpStatusBuilder>{
  public HTTPFaultInjectionAbortHttpStatusBuilder() {
    this(false);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(Boolean validationEnabled) {
    this(new HTTPFaultInjectionAbortHttpStatus(), validationEnabled);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HTTPFaultInjectionAbortHttpStatus(), validationEnabled);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatusFluent<?> fluent,HTTPFaultInjectionAbortHttpStatus instance) {
    this(fluent, instance, false);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatusFluent<?> fluent,HTTPFaultInjectionAbortHttpStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new HTTPFaultInjectionAbortHttpStatus());

    if (instance != null) {
      fluent.withHttpStatus(instance.getHttpStatus());
      fluent.withHttpStatus(instance.getHttpStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatus instance) {
    this(instance,false);
  }
  public HTTPFaultInjectionAbortHttpStatusBuilder(HTTPFaultInjectionAbortHttpStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new HTTPFaultInjectionAbortHttpStatus());

    if (instance != null) {
      this.withHttpStatus(instance.getHttpStatus());
      this.withHttpStatus(instance.getHttpStatus());
    }
    this.validationEnabled = validationEnabled; 
  }
  HTTPFaultInjectionAbortHttpStatusFluent<?> fluent;
  Boolean validationEnabled;
  public HTTPFaultInjectionAbortHttpStatus build() {
    HTTPFaultInjectionAbortHttpStatus buildable = new HTTPFaultInjectionAbortHttpStatus(fluent.getHttpStatus());
    return buildable;
  }
  
}
